# datamallet

Datamallet is a collection of helpful functions and modules for the datascience workflow. At the moment, it features the following:
1) Automated data visualization.<br>
2) Common scikit-learn transformers for data manipulation for tabular data.